pub struct TlsConnector { /* private fields */ }Expand description
Connector service factory using rustls.
Implementations
sourceimpl TlsConnector
impl TlsConnector
sourcepub fn new(connector: Arc<ClientConfig>) -> Self
pub fn new(connector: Arc<ClientConfig>) -> Self
Constructs new connector service factory from a rustls client configuration.
sourcepub fn service(connector: Arc<ClientConfig>) -> TlsConnectorService
pub fn service(connector: Arc<ClientConfig>) -> TlsConnectorService
Constructs new connector service from a rustls client configuration.